@@ -7,18 +7,14 @@
 # modification, are permitted under the terms of the BSD License. See
 # LICENSE file in the root of the Project.
 
-try:
-    from sys import maxint
-except ImportError:
-    from sys import maxsize as maxint
+from sys import maxsize
+
 import numpy as np
 from inspect import isclass
-from six import string_types
 try:
     from collections.abc import OrderedDict
 except ImportError:
     from collections import OrderedDict
-import sys
 
 from .util import find as finders
 from .compression import Compression
@@ -302,13 +298,6 @@ class Block(Entity):
             return self.data_frames[objid]
 
         util.check_entity_name_and_type(name, type_)
-        if (isinstance(col_dict, dict)
-                and not isinstance(col_dict, OrderedDict)
-                and sys.version_info[0] < 3):
-            raise TypeError("Cannot create a DataFrame from a dictionary "
-                            "in Python 2 as the order of keys is not "
-                            "preserved. Please use the OrderedDict class "
-                            "from the collections module instead.")
 
         if data is not None:
             shape = len(data)
@@ -358,10 +347,9 @@ class Block(Entity):
         if col_dict is not None:
             for nam, dt in col_dict.items():
                 if isclass(dt):
-                    if any(issubclass(dt, st) for st in string_types) \
-                            or issubclass(dt, np.string_):
+                    if issubclass(dt, (str, np.bytes_)):
                         col_dict[nam] = util.vlen_str_dtype
-                if 'U' in str(dt) or dt == np.string_:
+                if 'U' in str(dt) or dt == np.bytes_:
                     col_dict[nam] = util.vlen_str_dtype
             dt_arr = list(col_dict.items())
             col_dtype = np.dtype(dt_arr)
@@ -398,7 +386,7 @@ class Block(Entity):
         :rtype: list of nixio.Source
         """
         if limit is None:
-            limit = maxint
+            limit = maxsize
         return finders._find_sources(self, filtr, limit)
 
     def pprint(self, indent=2, max_length=120, extra=True, start_depth=0):
