@@ -6,12 +6,11 @@
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted under the terms of the BSD License. See
 # LICENSE file in the root of the Project.
-from __future__ import (absolute_import, division, print_function)
 from .util import units
 from .dimension_type import DimensionType
 
 
-class ValidationError(object):
+class ValidationError:
     """
     Static class for defining validation error messages
     """
@@ -78,7 +77,7 @@ class ValidationError(object):
     NoLinkType = "link_type is not set"
 
 
-class ValidationWarning(object):
+class ValidationWarning:
     NoVersion = "version is not set"
     NoFormat = "format is not set"
     NoFileID = "file ID is not set"
